@@ -111,6 +111,7 @@ enum class AllocKind : uint8_t {
     FAT_INLINE_ATOM,
     ATOM,
     SYMBOL,
+    BIGINT,
     JITCODE,
     SCOPE,
     REGEXP_SHARED,
@@ -151,6 +152,7 @@ enum class AllocKind : uint8_t {
     D(FAT_INLINE_ATOM,     String,        js::FatInlineAtom, js::FatInlineAtom) \
     D(ATOM,                String,        js::NormalAtom,    js::NormalAtom) \
     D(SYMBOL,              Symbol,        JS::Symbol,        JS::Symbol) \
+    D(BIGINT,              BigInt,        JS::BigInt,        JS::BigInt) \
     D(JITCODE,             JitCode,       js::jit::JitCode,  js::jit::JitCode) \
     D(SCOPE,               Scope,         js::Scope,         js::Scope) \
     D(REGEXP_SHARED,       RegExpShared,  js::RegExpShared,  js::RegExpShared)
