@@ -25,9 +25,6 @@ class Debugger;
 class TypedObjectModuleObject;
 class LexicalEnvironmentObject;
 
-class SimdTypeDescr;
-enum class SimdType;
-
 /*
  * Global object slots are reserved as follows:
  *
@@ -482,17 +479,6 @@ class GlobalObject : public NativeObject
                                  initTypedObjectModule);
     }
 
-    static JSObject*
-    getOrCreateSimdGlobalObject(JSContext* cx, Handle<GlobalObject*> global) {
-        return getOrCreateObject(cx, global, APPLICATION_SLOTS + JSProto_SIMD, initSimdObject);
-    }
-
-    // Get the type descriptor for one of the SIMD types.
-    // simdType is one of the JS_SIMDTYPEREPR_* constants.
-    // Implemented in builtin/SIMD.cpp.
-    static SimdTypeDescr*
-    getOrCreateSimdTypeDescr(JSContext* cx, Handle<GlobalObject*> global, SimdType simdType);
-
     TypedObjectModuleObject& getTypedObjectModule() const;
 
     JSObject* getLegacyIteratorPrototype() {
@@ -869,10 +855,6 @@ class GlobalObject : public NativeObject
     // Implemented in builtin/TypedObject.cpp
     static bool initTypedObjectModule(JSContext* cx, Handle<GlobalObject*> global);
 
-    // Implemented in builtin/SIMD.cpp
-    static bool initSimdObject(JSContext* cx, Handle<GlobalObject*> global);
-    static bool initSimdType(JSContext* cx, Handle<GlobalObject*> global, SimdType simdType);
-
     static bool initStandardClasses(JSContext* cx, Handle<GlobalObject*> global);
     static bool initSelfHostingBuiltins(JSContext* cx, Handle<GlobalObject*> global,
                                         const JSFunctionSpec* builtins);
